@@ -1,3 +1,7 @@
+"""
+Catalog search functionality
+"""
+
 from pathlib import Path
 from typing import Dict, Union, List
 
@@ -9,6 +13,7 @@ from tqdm import tqdm
 
 from up42.auth import Auth
 from up42.tools import Tools
+from up42.viztools import VizTools
 from up42.utils import get_logger, any_vector_to_fc, fc_to_query_geometry
 
 logger = get_logger(__name__)
@@ -31,30 +36,30 @@ supported_sensors = {
     },
     "sentinel1": {
         "blocks": [
-            "sobloo-sentinel1-l1c-grd-full",
-            "sobloo-sentinel1-l1c-grd-aoiclipped",
-            "sobloo-sentinel1-l1c-slc-full",
+            "sobloo-s1-grd-fullscene",
+            "sobloo-s1-grd-aoiclipped",
+            "sobloo-s1-slc-fullscene",
         ],
         "provider": "sobloo-image",
     },
     "sentinel2": {
         "blocks": [
-            "sobloo-sentinel2-lic-msi-full",
-            "sobloo-sentinel2-lic-msi-aoiclipped",
+            "sobloo-s2-l1c-fullscene",
+            "sobloo-s2-l1c-aoiclipped",
         ],
         "provider": "sobloo-image",
     },
-    "sentinel3": {"blocks": ["sobloo-sentinel3-full"], "provider": "sobloo-image"},
+    "sentinel3": {"blocks": ["sobloo-s3"], "provider": "sobloo-image"},
     "sentinel5p": {
         "blocks": [
-            "sobloo-sentinel5-preview-full",
+            "sobloo-s5p",
         ],
         "provider": "sobloo-image",
     },
 }
 
 # pylint: disable=duplicate-code
-class Catalog(Tools):
+class Catalog(VizTools, Tools):
     def __init__(self, auth: Auth):
         """
         The Catalog class enables access to the UP42 catalog search. You can search
@@ -224,7 +229,7 @@ class Catalog(Tools):
     ) -> List[str]:
         """
         Gets the quicklooks of scenes from a single sensor. After download, can
-        be plotted via catalog.plot_quicklooks().
+        be plotted via catalog.plot_quicklooks() or catalog.map_quicklooks().
 
         Args:
             image_ids: List of provider image_ids e.g. ["6dffb8be-c2ab-46e3-9c1c-6958a54e4527"].
